@@ -1,5 +1,7 @@
 #! /usr/bin/env python
-"""Configures the vector accumulators on all X engines.
+"""Configures the vector accumulators' period on all X engines.
+Revs:
+2010-11-13: JRM Pause output before changing acc time.
 """
 import corr, time, sys, numpy, os, logging
 
@@ -26,8 +28,8 @@ if __name__ == '__main__':
     p.set_description(__doc__)
     p.add_option('-t', '--time', dest='acc_time', type='float', default=-1,
         help="Specify the how long you'd like to accumulate (in seconds). Default: from config")
-    p.add_option('-v', '--verbose', dest='verbose',action='store_true', default=False,
-        help='Be verbose about errors.')
+    p.add_option('-s', '--no_restart', dest='no_restart',action='store_true', default=False,
+        help='Do not restart output after reconfiguring the VACC.')
 
     opts, args = p.parse_args(sys.argv[1:])
 
@@ -48,10 +50,20 @@ try:
     else:
         acc_time=c.config['int_time']
 
+    print ('''Pausing output...'''),
+    c.tx_stop()
+    print 'done.'
+
     print (''' Setting the accumulation period to %2.2f seconds...'''%(acc_time)),
     sys.stdout.flush()
     c.acc_time_set(acc_time)
-    print 'done, wrote %i into acc_len.'%(c.config['acc_len'])
+    print 'done, wrote %i into acc_len (%5.3fs).'%(c.config['acc_len'],c.config['int_time'])
+
+    print ('''Restarting output...'''),
+    if opts.no_restart == False: 
+        c.tx_start()
+        print 'done.'
+    else: print 'skipped.'
 
 except KeyboardInterrupt:
     exit_clean()
