@@ -4,6 +4,10 @@
 Reads the values of the RMS amplitude accumulators on the ibob through the X engine's XAUI connection.\n
 
 Revisions:
+2011-01-04  JRM Moved scroller screen teardown into try statement so that it doesn't clobber real error messages in the event that it wasn't instantiated in the first place.
+2010-12-11  JRM Removed bit estimate printing.
+                ADC overrange now just shows flag, does not cover amplitude text.
+                ncurses scroller fix to allow fast scrolling of screen.
 1.32 JRM swapped corr.rst_cnt for corr.rst_fstat and swapped column for RMS levels in dB.
 1.31 PVP Changed to accomodate change to corr_functions.adc_amplitudes_get() function - key in return dict changed from rms to rms_raw
 1.30 PVP Change to ncurses interface with ability to clear error statuses using corr.rst_cnt 
@@ -15,13 +19,13 @@ Revisions:
 import corr, time, numpy, struct, sys, logging
 
 def exit_fail():
-    scroller.screenTeardown()
     print 'FAILURE DETECTED. Log entries:\n', lh.printMessages()
     print "Unexpected error:", sys.exc_info()
     try:
+        scroller.screenTeardown()
         c.disconnect_all()
     except: pass
-    #raise
+    raise
     exit()
 
 def exit_clean():
@@ -53,20 +57,23 @@ try:
     # set up the curses scroll screen
     scroller = corr.scroll.Scroll()
     scroller.screenSetup()
-    scroller.setInstructionString(scroller.getInstructionString() + " A toggles auto-clear, C to clear once.")
+    scroller.setInstructionString("A toggles auto-clear, C to clear once.")
     # main program loop
     lastUpdate = time.time() - 3
     autoClear = False
     clearOnce = False
+    screenData = []
     while(True):
         # get key presses from ncurses
         keyPress = scroller.processKeyPress()
-        gotNewKey = keyPress[0] != 0
-        if (keyPress[1] == 'a') or (keyPress[1] == 'A'):
-            autoClear = not autoClear
-        elif (keyPress[1] == 'c') or (keyPress[1] == 'C'):
-            clearOnce = True
-        if (time.time() > (lastUpdate + 1)) or gotNewKey:
+        if keyPress[0] > 0:
+            if (keyPress[1] == 'a') or (keyPress[1] == 'A'):
+                autoClear = not autoClear
+            elif (keyPress[1] == 'c') or (keyPress[1] == 'C'):
+                clearOnce = True
+            scroller.drawScreen(screenData)
+
+        if (time.time() > (lastUpdate + 1)):
             screenData = []
             # get the data
             amps = c.adc_amplitudes_get()
@@ -74,25 +81,27 @@ try:
             if autoClear or clearOnce:
                 c.rst_fstat()
                 clearOnce = False
-            screenData.append('IBOB: ADC0 is bottom (furthest from power port), ADC1 is top (closest to power port).')
+            screenData.append('IBOB: ADC0 is furthest from power port, ADC1 is closest to power port.')
             screenData.append('ROACH: ADC0 is right, ADC1 is left (when viewed from front).')
             screenData.append('ADC input amplitudes averaged %i times.' % c.config['adc_levels_acc_len'])
             screenData.append('------------------------------------------------')
             for ant,pol in sorted(amps):
                 ffpga_n, xfpga_n, fxaui_n, xxaui_n, feng_input = c.get_ant_location(ant,pol)
-                displayString = 'Ant %i pol %s (%s input %i): ' % (ant, pol, c.fsrvs[ffpga_n], feng_input)
-                if stats[(ant, pol)]['adc_overrange']:
-                    displayString += 'ADC OVERRANGE.'
-                elif c.config['adc_type'] == 'katadc':
-                    displayString += ' %6.2f dBm (%2.2f bits used) with preamp of %5.1fdB.' % (amps[(ant, pol)]['rms_db'], amps[(ant, pol)]['bits'],c.rf_status_get(ant,pol)[1])
+                displayString = 'Ant %i%s (%s in%i): ' % (ant, pol, c.fsrvs[ffpga_n], feng_input)
+                if c.config['adc_type'] == 'katadc':
+                    preamp=c.rf_status_get(ant,pol)[1]
+                    displayString += ' %6.2f dBm with preamp of %5.1fdB = %6.2fdBm.' % (amps[(ant, pol)]['rms_db']+preamp,preamp,amps[(ant, pol)]['rms_db'])
                 else:
-                    displayString += ' %.3f (%2.2f bits used)' % (amps[(ant, pol)]['rms_raw'], amps[(ant, pol)]['bits'])
+                    displayString += ' %.3f' % (amps[(ant, pol)]['rms_raw'])
+                if stats[(ant, pol)]['adc_overrange']:
+                    displayString += ' ADC OVERRANGE!'
                 screenData.append(displayString)
             screenData.append("")
             if autoClear: screenData.append("Auto-clear ON.")
             else: screenData.append("Auto-clear OFF.")
             scroller.drawScreen(screenData)
             lastUpdate = time.time()
+            time.sleep(0.1)
 
 except KeyboardInterrupt:
     exit_clean()
