@@ -1,5 +1,7 @@
 #! /usr/bin/env python
 """Arms the F engines and resets the cumulative error counters on the X engine.
+Rev:
+2010-11-26  JRM Resync VACC after arm.
 """
 import corr, time, sys, numpy, os, logging
 
@@ -47,6 +49,11 @@ try:
     print 'Armed. Expect trigg at %s local (%s UTC).'%(time.strftime('%H:%M:%S',time.localtime(trig_time)),time.strftime('%H:%M:%S',time.gmtime(trig_time))),
     print 'SPEAD packet sent.'
 
+    print('Resyncing VACCs...'),
+    sys.stdout.flush()
+    c.vacc_sync()
+    print 'done.'
+
     print('Resetting error counters...'),
     sys.stdout.flush()
     c.rst_cnt()
