@@ -1,12 +1,16 @@
 #! /usr/bin/env python
 """ 
-Script for initialising casper_n correlators. Requires X engine version 330 and F engine 310 or greater.\n
+Script for initialising casper_n correlators. Requires X engine version 330 and F engine 310 or greater.
 
-Author: Jason Manley\n
-Revisions:\n
-2010-11-08  JRM Update to include f engines that output 10GbE
-2010-08-08  JRM Changed order of execution to match dataflow.
-2010-08-05  JRM Mods at GMRT for int time, feng clock, vacc sync checks etc.
+Author: Jason Manley
+"""
+"""
+Revisions:
+2011-02-11  JRM Added commandline option to skip clock check.
+2010-12-13  JRM Stop data transmission before initialising anything.\n
+2010-11-08  JRM Update to include f engines that output 10GbE\n
+2010-08-08  JRM Changed order of execution to match dataflow.\n
+2010-08-05  JRM Mods at GMRT for int time, feng clock, vacc sync checks etc.\n
 2010-07-20  JRM Mods to use ROACH based F engines.\n 
 2010-04-02  JCL Removed base_ant0 software register from Xengines, moved it to Fengines, and renamed it to use ibob_addr0 and ibob_data0.  Use function write_ibob() from corr_functions.py to set antenna offsets on Fengines
 2010-01-06  JRM Added output control and self-check after primary init.
@@ -59,6 +63,8 @@ if __name__ == '__main__':
         help='Skip configuring the 10GbE cores (ie starting tgtap drivers).  Default: start all drivers')
     p.add_option('-o', '--skip_output_config', dest='config_output',action='store_false', default=True, 
         help='Do not begin outputting packetised data.  Default: start the output.')
+    p.add_option('-k', '--clk_chk', dest='clk_chk',action='store_false', default=True, 
+        help='Skip the F engine clock checks.')
     p.add_option('-v', '--verbose', dest='verbose',action='store_true', default=False, 
         help='Be verbose about errors.')
     p.add_option('-s', '--spead', dest='spead',action='store_false', default=True, 
@@ -71,6 +77,7 @@ if __name__ == '__main__':
         exit()
     verbose=opts.verbose
     prog_fpga=opts.prog_fpga
+    check_clocks = opts.clk_chk
 
 lh=corr.log_handlers.DebugLogHandler(35)
 
@@ -101,21 +108,25 @@ try:
         print 'done.'
     else: print ' Skipped programming FPGAs.'
 
+    print ' Stopping transmission of data...',
+    c.tx_stop()
+    print 'done.'
+
     # Disable 10GbE cores until the network's been setup and ARP tables have settled. 
     # Need to do a reset here too to flush buffers in the core. But must be careful; resets are asynchronous and there must be no activity on the core (fifos) when they are reset.
     #DO NOT RESET THE 10GBE CORES SYNCHRONOUSLY... Packets will be routed strangely!
     print('\n Pausing 10GbE data exchange...'),
     sys.stdout.flush()
     if c.config['feng_out_type'] == '10gbe':
+        print "Pausing Fengs...",
         c.feng_ctrl_set_all(gbe_enable=False, gbe_rst=False)
         c.feng_ctrl_set_all(gbe_enable=False, gbe_rst=True)
         c.syslogger.info("Holding F engine 10GbE cores in reset.")
-        print "Fengs paused...",
 
+    print "Pausing Xengs...",
     c.xeng_ctrl_set_all(gbe_enable=False, gbe_rst=False)
     c.xeng_ctrl_set_all(gbe_enable=False, gbe_rst=True)
     c.syslogger.info("Holding X engine 10GbE cores in reset.")
-    print "Xengs paused...",
     print 'done.'
 
 
@@ -127,10 +138,12 @@ try:
 
     print(''' Checking F engine clocks...'''),
     sys.stdout.flush()
-    if c.check_feng_clks(): print 'ok'
-    else: 
-        print ('FAILURES detected!')
-        raise RuntimeError("System doesn't work with broken clocks!")
+    if check_clocks:
+        if c.check_feng_clks(): print 'ok'
+        else: 
+            print ('FAILURES detected!')
+            raise RuntimeError("System doesn't work with broken clocks!")
+    else: print 'skipped.'
 
     print(''' Setting the board indices...'''),
     sys.stdout.flush()
@@ -166,7 +179,7 @@ try:
 
         print(''' Waiting for ARP to complete...'''),
         sys.stdout.flush()
-        sleep_time=((c.config['10gbe_ip']&255 + c.config['n_xeng']*c.                config['n_xaui_ports_per_xfpga'])*0.1)
+        sleep_time=((c.config['10gbe_ip']&255 + c.config['n_xeng']*c.config['n_xaui_ports_per_xfpga'])*0.1)
         c.syslogger.info("Waiting %i seconds for ARP to complete."%sleep_time)
         time.sleep(sleep_time)
         print '''done'''
@@ -267,7 +280,7 @@ try:
         c.check_x_miss(verbose=True)
         exit_fail()
 
-    print (''' Setting the number of accumulations to %i (%2.2f seconds) and syncing VACCs...'''%(c.config['n_accs'],c.config['int_time'])),
+    print (''' Setting the number of accumulations to %i (%5.3f seconds) and syncing VACCs...'''%(c.config['n_accs'],c.config['int_time'])),
     sys.stdout.flush()
     c.acc_time_set()
     c.rst_cnt()
@@ -297,7 +310,7 @@ try:
 
     print ' Configuring output to %s:%i...'%(c.config['rx_udp_ip_str'],c.config['rx_udp_port']),
     sys.stdout.flush()
-    if opts.config_output: 
+    if opts.config_output and (c.config['out_type'] == '10gbe'): 
         c.config_udp_output()
         print 'done'
     else: print 'skipped.'
