@@ -8,7 +8,7 @@ from optparse import OptionParser
 from katcp.kattypes import request, return_reply, Float, Int, Str,struct
 
 
-logging.basicConfig(level=logging.INFO,
+logging.basicConfig(level=logging.WARN,
                     stream=sys.stderr,
                     format="%(asctime)s - %(name)s - %(filename)s:%(lineno)s - %(levelname)s - %(message)s")
 
@@ -61,10 +61,12 @@ class DeviceExampleServer(katcp.DeviceServer):
 
         for logent in self.c.log_handler._records:
             if logent.exc_info:
-                self.reply_inform(sock, katcp.Message.inform(orgmsg.name,'%s: %s Exception: '%(logent.name,logent.msg),logent.exc_info[0:-1]),orgmsg)        
+                print '%s: %s Exception: '%(logent.name,logent.msg),logent.exc_info[0:-1]
+                self.reply_inform(sock, katcp.Message.inform("log",'%s: %s Exception: '%(logent.name,logent.msg),logent.exc_info[0:-1]),orgmsg)        
             else:
 #log error 1234567 basic "the error string"
-                self.reply_inform(sock, katcp.Message.inform("log", logent.levelname.lower(),'%i'%(logent.created*1000), logent.name ,logent.msg),orgmsg)
+                self.reply_inform(sock, katcp.Message.inform("log",logent.levelname.lower(),'%i'%(logent.created*1000), logent.name ,logent.msg),orgmsg)
+                #print 'Sending this message:',logent.msg
         return ("ok", len(self.c.log_handler._records))
 
     @request()
@@ -104,14 +106,14 @@ class DeviceExampleServer(katcp.DeviceServer):
             return ("fail","Something broke. Check the log.")
             
     @request()
-    @return_reply()
+    @return_reply(Str())
     def request_tx_status(self, sock):
         """Check the TX status. Returns enabled or disabled."""
         if self.c is None:
             return ("fail","... you haven't connected yet!")
         try:
-            if self.c.tx_status_get(): return("enabled",)
-            else: return("disabled",)
+            if self.c.tx_status_get(): return("ok","enabled")
+            else: return("ok","disabled")
         except:
             return ("fail","Couldn't complete the request. Something broke. Check the log.")
             
