@@ -17,7 +17,7 @@ Revisions:
                 Fixed number of bits calculation
 
 '''
-import corr, time, numpy, struct, sys, logging, stats
+import corr, time, numpy, struct, sys, logging
 
 #brams
 brams=['bram_msb','bram_lsb','bram_oob']
