@@ -10,7 +10,7 @@ Author: Jason Manley
 Revisions:
 2010-07-22: JRM Copied from corr_snap_xaui.py
 '''
-import corr, time, numpy, struct, sys, logging, stats
+import corr, time, numpy, struct, sys, logging
 
 #brams
 brams=['bram_msb','bram_lsb','bram_oob']
