@@ -61,6 +61,29 @@ try:
         sys.stdout.flush()
         c.enable_udp_output()
         print 'done.'
+
+        print "Sending meta data to %s:%i."%(c.config['rx_meta_ip_str'],c.          config['rx_udp_port'])
+         
+        print ''' Issuing data descriptors...''',
+        sys.stdout.flush()
+        c.spead_data_descriptor_issue()
+        print 'SPEAD packet sent.'
+        
+        print ''' Issuing static metadata...''',
+        sys.stdout.flush()
+        c.spead_static_meta_issue()
+        print 'SPEAD packet sent.'
+        
+        print ''' Issuing timing metadata...''',
+        sys.stdout.flush()
+        c.spead_time_meta_issue()
+        print 'SPEAD packet sent.'
+        
+        print ''' Issuing eq metadata...''',
+        sys.stdout.flush()
+        c.spead_eq_meta_issue()
+        print 'SPEAD packet sent.'
+
     if opts.txStop:
         print 'Stopping TX...',
         sys.stdout.flush()
