@@ -546,18 +546,22 @@ class FpgaClient(BlockingClient):
          assert((type(qdr)==int))
          self.write_int('qdr%i_ctrl'%qdr,0xffffffff,blindwrite=True)
 
-    def get_snap(self,dev_name,brams,man_trig=False,man_valid=False,wait_period=1,offset=-1,       circular_capture=False):
+    def get_snap(self, dev_name, brams, man_trig=False, man_valid=False, wait_period=1, offset=-1, circular_capture=False):
         """Grabs all brams from a single snap block on this FPGA device.\n
             \tdev_name: string, name of the snap block.\n
             \tman_trig: boolean, Trigger the snap block manually.\n
             \toffset: integer, wait this number of valids before beginning capture. Set to negative value if    your hardware doesn't support this or the circular capture function.\n
             \tcircular_capture: boolean, Enable the circular capture function.\n
-            \twait_period: integer, wait this number of seconds between triggering and trying to read-back the data.\n
+            \twait_period: integer, wait this number of seconds between triggering and trying to read-back the data. Make it negative to wait forever.\n
             \tbrams: list, names of the bram components.\n
             \tRETURNS: dictionary with keywords: \n
             \t\tlengths: list of integers matching number of valids captured off each fpga.\n
             \t\toffset: optional (depending on snap block version) list of number of valids elapsed since last  trigger on each fpga.
             \t\t{brams}: list of data from each fpga for corresponding bram.\n"""
+        #2011-02-03 JRM added circular capture to trigger statement. 
+        #               Invert logic for end detect. 
+        #               Added wait forever option.
+        #               copy-paste errors from corr_functions :( really need to consolodate these snap functions.
         #2010-02-19 JRM Updated to match snap_x.
         #WORKING OK 2009-07-01
         if offset >= 0:
@@ -565,14 +569,14 @@ class FpgaClient(BlockingClient):
             #print 'Capturing from snap offset %i'%offset
 
         #print 'Triggering Capture...',
-        self.write_int(dev_name+'_ctrl',(0 + (man_trig<<1) + (man_valid<<2)))
-        self.write_int(dev_name+'_ctrl',(1 + (man_trig<<1) + (man_valid<<2)))
+        self.write_int(dev_name+'_ctrl',(0 + (man_trig<<1) + (man_valid<<2) + (circular_capture<<3)))
+        self.write_int(dev_name+'_ctrl',(1 + (man_trig<<1) + (man_valid<<2) + (circular_capture<<3)))
 
         done=False
         start_time=time.time()
-        while not (done and (offset>0 or circular_capture)) and ((time.time()-start_time)<wait_period):
+        while not (done and (offset!=0 or circular_capture)) and ((time.time()-start_time)<wait_period or (wait_period < 0)):
             addr = self.read_uint(dev_name+'_addr')
-            done = bool(addr & 0x80000000)
+            done = not bool(addr & 0x80000000)
 
         bram_size= self.read_uint(dev_name+'_addr')&0x7fffffff
         bram_dmp=dict()
@@ -580,21 +584,19 @@ class FpgaClient(BlockingClient):
         bram_dmp['offset']=0
         if (bram_size != self.read_uint(dev_name+'_addr')&0x7fffffff) or bram_size==0:
             #if address is still changing, then the snap block didn't finish capturing. we return empty.  
-            print "Looks like snap block didn't finish."
+            raise RuntimError("Looks like snap block didn't finish.")
             bram_dmp['length']=0
             bram_dmp['offset']=0
             bram_size=0
 
         if circular_capture or (offset>=0):
+            #print 'offset: %i,tr_en_cnt: %i'%(offset,self.read_uint(dev_name+'_tr_en_cnt'))
             bram_dmp['offset']=self.read_uint(dev_name+'_tr_en_cnt') + offset - bram_size
         else: bram_dmp['offset']=0
 
         if (bram_dmp['offset'] < 0):  
-            raise RuntimeError('SNAP block hardware or logic failure happened. Returning no data.')
-        #if offset<0, there was a big error. this should never happen. unless you held stop high while      resetting before inputting valid data during a circular capture? In any case, zero the output.
-            bram_dmp['length']=0
+            #you got a trigger and then a stop before the bram could even fill.
             bram_dmp['offset']=0
-            bram_size=0
 
         for b,bram in enumerate(brams):
             bram_path = dev_name+'_'+bram
