@@ -1,5 +1,10 @@
 """
 Playing with ncurses in Python to scroll up and down, left and right, through a list of data that is periodically refreshed. 
+
+Revs:
+2010-12-11  JRM Added concat for status line to prevent bailing on small terminals.
+                Code cleanup to prevent modification of external variables.
+                Added left,right page controls
 """
 
 import curses, sys
@@ -7,7 +12,7 @@ import curses, sys
 class Scroll:
 
     # what should be printed at the bottom of the screen?
-    instructionString = "Scroll with arrow keys. U page up, D page down, H home, Q quit."
+    instructionString = ""
 
     # at which row and col must we draw the screen output?
     offsetV = 0
@@ -36,16 +41,20 @@ class Scroll:
     # act on certain keys
     def processKeyPress(self):
         key = self.screen.getch()
-        if key == 113: raise KeyboardInterrupt		# q for quit
-        elif key == 117: self.offsetV -= curses.LINES   # u - pg up
-        elif key == 100: self.offsetV += curses.LINES   # d - pg down
-        elif key == 104: self.offsetH = 0               # h - home
-        elif key == 65: self.offsetV -= 1               # up
-        elif key == 66: self.offsetV += 1               # down
-        elif key == 67: self.offsetH += 1               # right
-        elif key == 68: self.offsetH -= 1               # left
-        if key < 0: key = 0
-        return [key, chr(key)]
+        if key > 0: 
+            if chr(key) == 'q': raise KeyboardInterrupt		# q for quit
+            elif chr(key) == 'u': self.offsetV -= curses.LINES 
+            elif chr(key) == 'd': self.offsetV += curses.LINES  
+            elif chr(key) == 'l': self.offsetH += curses.COLS  
+            elif chr(key) == 'r': self.offsetH -= curses.COLS 
+            elif chr(key) == 'h': self.offsetH = 0; self.offsetV=0 
+            elif key == 65: self.offsetV -= 1               # up
+            elif key == 66: self.offsetV += 1               # down
+            elif key == 67: self.offsetH -= 1               # right
+            elif key == 68: self.offsetH += 1               # left
+            return [key,chr(key)]
+        else:
+            return [0,chr(0)]
 
     # clear the screen
     def clearScreen(self):
@@ -66,8 +75,8 @@ class Scroll:
         # clear the screen
         self.screen.clear()
         numLinesTotal = len(data)
-        # reserve the bottom line for instructions
-        numLinesAvailable = curses.LINES - 1
+        # reserve the bottom three lines for instructions
+        numLinesAvailable = curses.LINES -1 
         # can we fit everything on the screen?
         topLine = 0
         if numLinesTotal > numLinesAvailable:
@@ -84,12 +93,12 @@ class Scroll:
         self.currentLinePosition = 0
         for lineNum in range(topLine, bottomLine):
             #data[lineNum] = "%03i-%03i-%03i-%03i-" % (topLine, lineNum, self.offsetV, self.offsetH) + data[lineNum]
-            # truncate long lines...
-            data[lineNum] = data[lineNum][-1 * self.offsetH:(-1 * self.offsetH) + curses.COLS]
-            # and add the data to the screen
-            self.screen.addstr(self.currentLinePosition, 0, data[lineNum] + '\n')
+            # truncate long lines and add the data to the screen
+            self.screen.addstr(self.currentLinePosition, 0, (data[lineNum][-1 * self.offsetH:(-1 * self.offsetH) + curses.COLS]) + '\n')
             self.currentLinePosition += 1
-        self.screen.addstr(numLinesAvailable, 0, "Showing line %i to %i of %i. Column offset %i. %s" % (topLine, bottomLine, numLinesTotal, self.offsetH, self.instructionString))
+        stat_line="Showing line %i to %i of %i. Column offset %i. %s Scroll with arrow keys. u,d,l,r=page up, down, left and right. h=home, q=quit." % (topLine, bottomLine, numLinesTotal, self.offsetH, self.instructionString)
+        stat_line=stat_line[-1 * self.offsetH:(-1 * self.offsetH) + (curses.COLS-1)]
+        self.screen.addstr(numLinesAvailable, 0, stat_line)
         self.screen.refresh()
 
     # set and get the instruction string at the bottom
